// Copyright 2000-2020 JetBrains s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.goide.testing;

import jetbrains.buildServer.messages.serviceMessages.ServiceMessageTypes;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.HashMap;
import java.util.Map;

public class ServiceMessageBuilder {
  private final String myMessageName;
  private final Map<String, String> myAttributes = new HashMap<String, String>();

  public ServiceMessageBuilder(@NotNull String messageName) {
    myMessageName = messageName;
  }

  public ServiceMessageBuilder attribute(@NotNull String name, @Nullable String value) {
    myAttributes.put(name, value);
    return this;
  }

  public GoTestServiceMessage build() {
    return new GoTestServiceMessage(myMessageName, myAttributes);
  }

  public static ServiceMessageBuilder testSuiteStarted(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_SUITE_STARTED).attribute("name", name);
  }

  public static ServiceMessageBuilder testSuiteFinished(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_SUITE_FINISHED).attribute("name", name);
  }

  public static ServiceMessageBuilder testStarted(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_STARTED).attribute("name", name);
  }

  public static ServiceMessageBuilder testFinished(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_FINISHED).attribute("name", name);
  }

  public static ServiceMessageBuilder testStdOut(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_STD_OUT).attribute("name", name);
  }

  public static ServiceMessageBuilder testStdErr(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_STD_ERR).attribute("name", name);
  }

  public static ServiceMessageBuilder testFailed(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_FAILED).attribute("name", name);
  }

  public static ServiceMessageBuilder testIgnored(@NotNull String name) {
    return new ServiceMessageBuilder(ServiceMessageTypes.TEST_IGNORED).attribute("name", name);
  }
}
